summaryrefslogtreecommitdiff
path: root/TAO/TAO_IDL/be/be_visitor_union_branch/public_reset_cs.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/TAO_IDL/be/be_visitor_union_branch/public_reset_cs.cpp')
-rw-r--r--TAO/TAO_IDL/be/be_visitor_union_branch/public_reset_cs.cpp11
1 files changed, 5 insertions, 6 deletions
diff --git a/TAO/TAO_IDL/be/be_visitor_union_branch/public_reset_cs.cpp b/TAO/TAO_IDL/be/be_visitor_union_branch/public_reset_cs.cpp
index e6723b1f654..62195e9fc7e 100644
--- a/TAO/TAO_IDL/be/be_visitor_union_branch/public_reset_cs.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_union_branch/public_reset_cs.cpp
@@ -125,7 +125,7 @@ be_visitor_union_branch_public_reset_cs::visit_array (be_array *node)
}
// for anonymous arrays, the type name has a _ prepended. We compute the
// fullname with or without the underscore and use it later on.
char fname [NAMEBUFSIZE]; // to hold the full and
// save the node's local name and full name in a buffer for quick use later
@@ -141,18 +141,18 @@ be_visitor_union_branch_public_reset_cs::visit_array (be_array *node)
if (bt->is_nested ())
{
be_decl *parent = be_scope::narrow_from_scope (bt->defined_in ())->decl ();
- ACE_OS::sprintf (fname, "%s::_%s", parent->fullname (),
+ ACE_OS::sprintf (fname, "%s::_%s", parent->full_name (),
bt->local_name ()->get_string ());
}
else
{
- ACE_OS::sprintf (fname, "_%s", bt->fullname ());
+ ACE_OS::sprintf (fname, "_%s", bt->full_name ());
}
}
else
{
// typedefed node
- ACE_OS::sprintf (fname, "%s", bt->fullname ());
+ ACE_OS::sprintf (fname, "%s", bt->full_name ());
}
os = this->ctx_->stream ();
@@ -371,8 +371,7 @@ be_visitor_union_branch_public_reset_cs::visit_structure (be_structure *node)
), -1);
}
os = this->ctx_->stream ();
- if (bt->size_type () == be_type::VARIABLE
- || node->has_constructor ())
+ if (bt->size_type () == be_type::VARIABLE)
{
*os << "delete this->u_." << ub->local_name ()
<< "_;" << be_nl
@@ -125,7 +125,7 @@ be_visitor_union_branch_public_reset_cs::visit_array (be_array *node)
}
// for anonymous arrays, the type name has a _ prepended. We compute the
- // fullname with or without the underscore and use it later on.
+ // full_name with or without the underscore and use it later on.
char fname [NAMEBUFSIZE]; // to hold the full and
// save the node's local name and full name in a buffer for quick use later